@@ -1,23 +1,35 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
     collapse = TRUE,
     comment = "#>"
 )
 
-## ----setup, message=FALSE-----------------------------------------------------
+## ----setup-load, message=FALSE, warning=FALSE, echo=FALSE---------------------
 library(rb3)
 library(ggplot2)
 library(stringr)
 library(dplyr)
 library(bizdays)
 
-df <- futures_mget(
-    first_date = "2021-01-01",
-    last_date = "2022-04-27",
-    by = 5
-)
+df <- try(futures_mget(first_date = "2021-01-01", last_date = "2022-04-27", by = 5), silent = TRUE)
+if (is(df, "try-error")) {
+  load("futures_mget-20210101_20220427.rda")
+}
 
-## ---- fig.width=9, fig.height=6-----------------------------------------------
+## ----setup, eval=FALSE--------------------------------------------------------
+#  library(rb3)
+#  library(ggplot2)
+#  library(stringr)
+#  library(dplyr)
+#  library(bizdays)
+#  
+#  df <- futures_mget(
+#      first_date = "2021-01-01",
+#      last_date = "2022-04-27",
+#      by = 5
+#  )
+
+## ----fig.width=9, fig.height=6------------------------------------------------
 di1_futures <- df |>
     filter(commodity == "DI1") |>
     mutate(
@@ -42,7 +54,7 @@ di1_futures |>
     ) +
     scale_y_continuous(labels = scales::percent)
 
-## ---- fig.width=9, fig.height=6-----------------------------------------------
+## ----fig.width=9, fig.height=6------------------------------------------------
 dap_futures <- df |>
     filter(commodity == "DAP") |>
     mutate(
@@ -67,7 +79,7 @@ dap_futures |>
     ) +
     scale_y_continuous(labels = scales::percent)
 
-## ---- warning=FALSE, fig.width=9, fig.height=6--------------------------------
+## ----warning=FALSE, fig.width=9, fig.height=6---------------------------------
 infl_futures <- df |>
     filter(symbol %in% c("DI1F23", "DAPF23")) |>
     mutate(
@@ -91,7 +103,7 @@ infl_expec |>
     geom_line() +
     geom_point()
 
-## ---- warning=FALSE, fig.width=9, fig.height=6--------------------------------
+## ----warning=FALSE, fig.width=9, fig.height=6---------------------------------
 df_fut <- df |>
     filter(symbol %in% c("DI1F23", "DI1F33")) |>
     mutate(
@@ -118,7 +130,7 @@ df_fwd <- df_fut |>
     select(refdate, fwd) |>
     na.omit()
 
-## ---- warning=FALSE, fig.width=9, fig.height=6--------------------------------
+## ----warning=FALSE, fig.width=9, fig.height=6---------------------------------
 df_fwd |>
     ggplot(aes(x = refdate, y = fwd)) +
     geom_line() +
